HolEInteraction
===============

.. currentmodule:: pykeen.nn.modules

.. autoclass:: HolEInteraction
   :show-inheritance:

   .. rubric:: Methods Summary

   .. autosummary::

      ~HolEInteraction.func

   .. rubric:: Methods Documentation

   .. automethod:: func
